/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RuleEditorController.as 4905 2009-08-13 13:35:13Z nicoulaj $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eos.rules.editor.control
{
import com.adobe.cairngorm.control.FrontController;

import org.ow2.jasmine.monitoring.eos.rules.common.event.*;
import org.ow2.jasmine.monitoring.eos.rules.editor.command.*;
import org.ow2.jasmine.monitoring.eos.rules.editor.event.*;
import org.ow2.jasmine.monitoring.eos.rules.editor.model.RuleEditorModelLocator;
import org.ow2.jasmine.monitoring.eos.rules.editor.model.domain.RuleEditorModel;


/**
* Bind a type of command to an action.
* 
* @author Julien Nicoulaud
*/
public class RuleEditorController extends FrontController {

    // =========================================================================
    // Initialization
    // =========================================================================

    /**
    * Create an instance of the controller. Commands are initialized here.
    */
    public function RuleEditorController()
    {
        initialiseCommands();
    }

    /**
    * Add all of the commands to the pool of commands.
    */
    public function initialiseCommands() : void
    {
        // Retrieve the component model
        var model:RuleEditorModel = 
            RuleEditorModelLocator.getInstance().ruleEditorModel;
        
        // Register the commands
        this.addCommand(RulePackageSystemNameEvent.GET_RULE_PACKAGE + model.componentID,
                        GetRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.UPDATE_RULE_PACKAGE_METADATA + model.componentID,
                        UpdateRulePackageMetadataCommand);
        this.addCommand(RulePackageSystemNameEvent.RELOAD_RULE_PACKAGE + model.componentID,
                        ReloadRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.SAVE_SYNCHRONIZED_RULE_PACKAGE + model.componentID,
                        SaveRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.SAVE_AND_CLOSE_SYNCHRONIZED_RULE_PACKAGE + model.componentID,
                        SaveRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.CONVERT_TO_TEXTUAL_PACKAGE + model.componentID,
                        ConvertToTextualPackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.CREATE_TEXTUAL_VERSION + model.componentID,
                        CreateTextualVersionCommand);
        this.addCommand(SynchronizedRulePackageEvent.COMPILE_RULE_PACKAGE + model.componentID,
                        CompileRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.CHECK_NAME_AVAILABILITY + model.componentID,
                        CheckSystemNameAvailabilityCommand);
        this.addCommand(RulePackagesEvent.EXPORT_RULE_PACKAGES_AS_XML + model.componentID,
                        ExportRulePackagesAsXMLCommand);
        this.addCommand(ServerFilePathEvent.IMPORT_RULE_PACKAGE + model.componentID,
                        ImportRulePackageCommand);
    }
}
}
