/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TextualEditorCodeArea.as 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.editor.view.editor.textual
{
import flash.events.Event;
import flash.events.KeyboardEvent;
import flash.events.MouseEvent;
import flash.geom.Point;
import flash.geom.Rectangle;

import mx.controls.Alert;
import mx.controls.ToolTip;
import mx.managers.ToolTipManager;

import org.ow2.jasmine.monitoring.eos.rules.common.view.DroolsCodeArea;


/**
* A TextArea for Drools rule packages edition. Displays a ToolTip when user tries
* to edit the "package" statement line.
*
* @author Julien Nicoulaud
* @see package org.ow2.jasmine.monitoring.eos.rules.common.view.DroolsCodeArea
* @see org.ow2.jasmine.monitoring.eos.common.controls.CodeArea
* @see org.ow2.jasmine.monitoring.eos.common.controls.LineNumberedTextArea
*/
public class TextualEditorCodeArea extends DroolsCodeArea
{
    // =========================================================================
    // Variables
    // =========================================================================
    
    /**
    * The package statement line tooltip
    */
    private var packageLineToolTip : ToolTip;


    // =========================================================================
    // Constructor
    // =========================================================================
    
    /**
    * Build a new TextualEditorCodeArea
    */
	public function TextualEditorCodeArea()
	{
		// Call super class constructor
		super();
                
		// Listen to text changing events
        addEventListener(KeyboardEvent.KEY_UP,onKeyDown);
	}
    

    // =========================================================================
    // Private methods
    // =========================================================================
    
    /**
    * When a key is pressed
    */
    private function onKeyDown(event:KeyboardEvent):void
    {
        // Retrieve the current line
        var currentLineIndex:int = 0;
        if (selectionBeginIndex > 0) {
            currentLineIndex =
                textField.getLineIndexOfChar(selectionBeginIndex);
            if (currentLineIndex == -1) {
                currentLineIndex = textField.getLineIndexOfChar(selectionBeginIndex-1);
            }
        }
        var currentLine:String =
            textField.getLineText(currentLineIndex);
        var packageStatementLine:RegExp = new RegExp("^package\\s.*","gmi");
        
        // If we are in the package statement line, and not just moving
        // or selecting the content
        if (currentLine.search(packageStatementLine) >= 0 &&
            !event.ctrlKey &&        // Ctrl key
            event.keyCode !== 33 &&  // Page up
            event.keyCode !== 34 &&  // Page down
            event.keyCode !== 35 &&  // End
            event.keyCode !== 36 &&  // Begin
            event.keyCode !== 37 &&  // Left
            event.keyCode !== 38 &&  // Up
            event.keyCode !== 39 &&  // Right
            event.keyCode !== 40     // Down
        ) {
            // Show the tooltip
            showPackageLineToolTip();
        }
        
        // Else hide the tooltip
        else if (packageLineToolTip !== null) {
            hidePackageLineToolTip();
        }
    }
    
    /**
    * Show the package statement line tooltip
    */
    private function showPackageLineToolTip(e:Event=null):void
    {
        if (packageLineToolTip == null) {
            var rect:Rectangle = textField.getCharBoundaries(selectionBeginIndex);
            if (rect!= null) {
                var pt:Point = new Point(rect.right,rect.bottom);
                pt = localToGlobal(pt);
                packageLineToolTip =
                    ToolTipManager.createToolTip("You should not edit the package statement line directly. " + 
                                                 "This is automatically generated from the name of the rule package, " + 
                                                 "all you have to do is to edit this name.",
                                                 pt.x,pt.y-verticalScrollPosition*textField.getLineMetrics(0).height,
                                                 "errorTipBelow") as ToolTip;
                packageLineToolTip.setStyle("borderColor", "#CC611E");
                packageLineToolTip.setStyle("color", "white");
                addEventListener(MouseEvent.MOUSE_DOWN,hidePackageLineToolTip);
                addEventListener(MouseEvent.MOUSE_OUT,hidePackageLineToolTip);
            }
        }
    }
    
    /**
    * Hide the package statement line tooltip
    */
    private function hidePackageLineToolTip(e:Event=null):void
    {
        if (packageLineToolTip !== null) {
            ToolTipManager.destroyToolTip(packageLineToolTip);
            packageLineToolTip = null;
        }
    }
    
}
}
